/**
 * TurboGUI is A library that helps with the most common and generic UI elements and functionalities
 *
 * Website : -> http://www.turbogui.org
 * License : -> Licensed under the Apache License, Version 2.0. You may not use this file except in compliance with the License.
 * License Url : -> http://www.apache.org/licenses/LICENSE-2.0
 * CopyRight : -> Copyright 2018 Edertone Advanded Solutions. https://www.edertone.com
 */
import { ErrorHandler } from '@angular/core';
import { SingletoneStrictClass } from '../model/classes/SingletoneStrictClass';
import * as i0 from "@angular/core";
/**
 * Captures all the application exceptions and performs any required action.
 * It also contains multiple general error management features.
 *
 * To define this class as your application error handler, you must add the following to your
 * Application providers:
 *      {
 *          provide: ErrorHandler,
 *          useClass: GlobalErrorService
 *      },
 *      GlobalErrorService
 *
 * You cannot access the error handler at runtime. If you need to modify any of the behaviours
 * or implement your custom ones, you must extend this class and set your new one as the error
 * handler provider.
 */
export declare class GlobalErrorService extends SingletoneStrictClass implements ErrorHandler {
    /**
     * Enables or disables the error notification to user via an alert box
     * Extend this class and override this value on your custom error handle to change it
     */
    private readonly showExceptionsToUser;
    /**
     * Enables or disables the error notification to user via an alert box
     * Extend this class and override this value on your custom error handle to change it
     */
    private readonly showExceptionsOnConsole;
    /**
     * Defines the text that will be used for the alert that is shown to the user when an exception happens
     * and showExceptionsToUser is true
     * Extend this class and override this value on your custom error handle to change it
     */
    private readonly errorAlertMessage;
    constructor();
    /**
     * Show an alert with the received error detail and also log it to the js console.
     *
     * Angular expects at least this method to be implemented on any class that is used as a global exception handler.
     *
     * @param error An error instance
     */
    handleError(error: any): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<GlobalErrorService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<GlobalErrorService>;
}
//# sourceMappingURL=globalerror.service.d.ts.map