/**
 * TurboGUI is A library that helps with the most common and generic UI elements and functionalities
 *
 * Website : -> http://www.turbogui.org
 * License : -> Licensed under the Apache License, Version 2.0. You may not use this file except in compliance with the License.
 * License Url : -> http://www.apache.org/licenses/LICENSE-2.0
 * CopyRight : -> Copyright 2018 Edertone Advanded Solutions. https://www.edertone.com
 */
import { OnInit } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * This is the base class for all button components
 */
export declare abstract class ButtonBaseComponent implements OnInit {
    /**
     * Defines the actual opacity that is binded on the html part
     */
    currentOpacity: number;
    /**
     * Defines the actual scale that is binded on the html part
     */
    currentScale: string;
    /**
     * Defines if the button can be clicked or not
     */
    pointerEvents: string;
    /**
     * Specifies if the button animations must rollback when the user releases the mouse or pointer after pressing it
     */
    releaseOnMouseUp: boolean;
    /**
     * Specifies the amount of milliseconds that the button will vibrate when it gets clicked (only on compatible devices and browsers)
     * Set it to 0 to disable click vibration
     */
    vibrateOnClick: number;
    /**
     * Defines the button opacity when it is not clicked
     */
    defaultOpacity: number;
    /**
     * Defines the image scale when it is not clicked
     */
    defaultScale: number;
    /**
     * Defines the button opacity when it is hovered
     */
    hoverOpacity: number;
    /**
     * Defines the image scale when it is hovered
     */
    hoverScale: number;
    /**
     * Defines the button opacity when it is clicked
     */
    clickOpacity: number;
    /**
     * Defines the image scale when it is clicked
     */
    clickScale: number;
    /**
     * Defines the button opacity when it is disabled
     */
    disabledOpacity: number;
    /**
     * Stores the value that tells if the button is enabled or disabled
     */
    private _enabled;
    /**
     * Specifies if the button is enabled or disabled
     */
    set enabled(v: boolean);
    /**
     * Set button default values
     */
    ngOnInit(): void;
    /**
     * Listens for the mouse over the button component
     */
    onMouseOver(): void;
    /**
     * Listens for the mouse out of the button component
     */
    onMouseOut(): void;
    /**
     * Listens for the mouse down on the button component
     */
    onMouseDown(): void;
    /**
     * Listens for the mouse up of the button component
     */
    onMouseUp(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ButtonBaseComponent, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ButtonBaseComponent, never, never, { "releaseOnMouseUp": { "alias": "releaseOnMouseUp"; "required": false; }; "vibrateOnClick": { "alias": "vibrateOnClick"; "required": false; }; "defaultOpacity": { "alias": "defaultOpacity"; "required": false; }; "defaultScale": { "alias": "defaultScale"; "required": false; }; "hoverOpacity": { "alias": "hoverOpacity"; "required": false; }; "hoverScale": { "alias": "hoverScale"; "required": false; }; "clickOpacity": { "alias": "clickOpacity"; "required": false; }; "clickScale": { "alias": "clickScale"; "required": false; }; "disabledOpacity": { "alias": "disabledOpacity"; "required": false; }; "enabled": { "alias": "enabled"; "required": false; }; }, {}, never, never, true, never>;
}
//# sourceMappingURL=button-base.component.d.ts.map